summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorxCrystal <rgr.crystal@gmail.com>2018-01-01 15:08:21 +0100
committerxCrystal <rgr.crystal@gmail.com>2018-01-01 20:09:53 +0100
commit37369d1ae0890c63b494937ed6234e68f46359c5 (patch)
treefbf4952ed70906c1a4b10fb8b9e5c490bc680cc8
parent6e12a515031027ab0412ef37a3f6e3b24adfc736 (diff)
Rename Pals labels in WRAM bank 5
-rw-r--r--engine/battle/battle_transition.asm18
-rw-r--r--engine/battle_anims/anim_commands.asm12
-rw-r--r--engine/battle_anims/bg_effects.asm16
-rwxr-xr-xengine/card_flip.asm2
-rw-r--r--engine/cgb_layouts.asm120
-rw-r--r--engine/color.asm54
-rw-r--r--engine/credits.asm8
-rwxr-xr-xengine/crystal_colors.asm34
-rwxr-xr-xengine/crystal_intro.asm60
-rwxr-xr-xengine/debug.asm10
-rwxr-xr-xengine/events/heal_machine_anim.asm4
-rw-r--r--engine/events/poisonstep_pals.asm2
-rwxr-xr-xengine/init_gender.asm2
-rw-r--r--engine/init_hof_credits.asm2
-rw-r--r--engine/pokedex.asm2
-rw-r--r--engine/timeofdaypals.asm8
-rw-r--r--engine/title.asm8
-rw-r--r--engine/unused_title.asm8
-rw-r--r--home.asm6
-rw-r--r--home/palettes.asm38
-rwxr-xr-xmobile/fixed_words.asm2
-rw-r--r--mobile/mobile_22.asm20
-rw-r--r--mobile/mobile_22_2.asm2
-rw-r--r--mobile/mobile_40.asm2
-rw-r--r--mobile/mobile_42.asm32
-rw-r--r--mobile/mobile_45.asm2
-rwxr-xr-xmobile/mobile_45_sprite_engine.asm10
-rwxr-xr-xmobile/mobile_46.asm2
-rwxr-xr-xmobile/mobile_5b.asm36
-rwxr-xr-xmobile/mobile_5c.asm8
-rw-r--r--mobile/mobile_5e.asm10
-rw-r--r--mobile/mobile_5f.asm24
-rw-r--r--tilesets/animations.asm10
-rw-r--r--tilesets/special_palettes.asm36
-rw-r--r--wram.asm8
35 files changed, 309 insertions, 309 deletions
diff --git a/engine/battle/battle_transition.asm b/engine/battle/battle_transition.asm
index f2fef5553..85ba44072 100644
--- a/engine/battle/battle_transition.asm
+++ b/engine/battle/battle_transition.asm
@@ -26,7 +26,7 @@ Predef_StartBattle: ; 8c20f
ld a, $5
ld [rSVBK], a
- ld hl, UnknBGPals
+ ld hl, wBGPals1
ld bc, 8 palettes
xor a
call ByteFill
@@ -651,11 +651,11 @@ StartTrainerBattle_LoadPokeBallGraphics: ; 8c5dc (23:45dc)
ld [rSVBK], a
call .copypals
push hl
- ld de, UnknBGPals palette PAL_BG_TEXT
+ ld de, wBGPals1 palette PAL_BG_TEXT
ld bc, 1 palettes
call CopyBytes
pop hl
- ld de, BGPals palette PAL_BG_TEXT
+ ld de, wBGPals2 palette PAL_BG_TEXT
ld bc, 1 palettes
call CopyBytes
pop af
@@ -670,17 +670,17 @@ StartTrainerBattle_LoadPokeBallGraphics: ; 8c5dc (23:45dc)
ret
.copypals ; 8c677 (23:4677)
- ld de, UnknBGPals palette PAL_BG_TEXT
+ ld de, wBGPals1 palette PAL_BG_TEXT
call .copy
- ld de, BGPals palette PAL_BG_TEXT
+ ld de, wBGPals2 palette PAL_BG_TEXT
call .copy
- ld de, UnknOBPals palette PAL_OW_TREE
+ ld de, wOBPals1 palette PAL_OW_TREE
call .copy
- ld de, OBPals palette PAL_OW_TREE
+ ld de, wOBPals2 palette PAL_OW_TREE
call .copy
- ld de, UnknOBPals palette PAL_OW_ROCK
+ ld de, wOBPals1 palette PAL_OW_ROCK
call .copy
- ld de, OBPals palette PAL_OW_ROCK
+ ld de, wOBPals2 palette PAL_OW_ROCK
.copy ; 8c698 (23:4698)
push hl
diff --git a/engine/battle_anims/anim_commands.asm b/engine/battle_anims/anim_commands.asm
index 2db8bf293..27d57e68f 100644
--- a/engine/battle_anims/anim_commands.asm
+++ b/engine/battle_anims/anim_commands.asm
@@ -1433,14 +1433,14 @@ BattleAnim_SetBGPals: ; cc91a
push af
ld a, $5
ld [rSVBK], a
- ld hl, BGPals
- ld de, UnknBGPals
+ ld hl, wBGPals2
+ ld de, wBGPals1
ld a, [rBGP]
ld b, a
ld c, 7
call CopyPals
- ld hl, OBPals
- ld de, UnknOBPals
+ ld hl, wOBPals2
+ ld de, wOBPals1
ld a, [rBGP]
ld b, a
ld c, 2
@@ -1461,8 +1461,8 @@ BattleAnim_SetOBPals: ; cc94b
push af
ld a, $5
ld [rSVBK], a
- ld hl, OBPals palette PAL_BATTLE_OB_GRAY
- ld de, UnknOBPals palette PAL_BATTLE_OB_GRAY
+ ld hl, wOBPals2 palette PAL_BATTLE_OB_GRAY
+ ld de, wOBPals1 palette PAL_BATTLE_OB_GRAY
ld a, [rOBP0]
ld b, a
ld c, 2
diff --git a/engine/battle_anims/bg_effects.asm b/engine/battle_anims/bg_effects.asm
index 537757b14..bb8feb1f9 100644
--- a/engine/battle_anims/bg_effects.asm
+++ b/engine/battle_anims/bg_effects.asm
@@ -2583,13 +2583,13 @@ BGEffects_LoadBGPal0_OBPal1: ; c8e52 (32:4e52)
ld a, h
push bc
push af
- ld hl, BGPals
- ld de, UnknBGPals
+ ld hl, wBGPals2
+ ld de, wBGPals1
ld b, a
ld c, $1
call CopyPals
- ld hl, OBPals palette 1
- ld de, UnknOBPals palette 1
+ ld hl, wOBPals2 palette 1
+ ld de, wOBPals1 palette 1
pop af
ld b, a
ld c, $1
@@ -2610,13 +2610,13 @@ BGEffects_LoadBGPal1_OBPal0: ; c8e7f (32:4e7f)
ld a, h
push bc
push af
- ld hl, BGPals palette 1
- ld de, UnknBGPals palette 1
+ ld hl, wBGPals2 palette 1
+ ld de, wBGPals1 palette 1
ld b, a
ld c, $1
call CopyPals
- ld hl, OBPals ; OBPals
- ld de, UnknOBPals ; wd040
+ ld hl, wOBPals2
+ ld de, wOBPals1
pop af
ld b, a
ld c, $1
diff --git a/engine/card_flip.asm b/engine/card_flip.asm
index 515f0ce79..158f3fa05 100755
--- a/engine/card_flip.asm
+++ b/engine/card_flip.asm
@@ -1652,7 +1652,7 @@ CardFlip_InitAttrPals: ; e0c37 (38:4c37)
ld a, $5
ld [rSVBK], a
ld hl, .palettes
- ld de, UnknBGPals
+ ld de, wBGPals1
ld bc, 9 palettes
call CopyBytes
pop af
diff --git a/engine/cgb_layouts.asm b/engine/cgb_layouts.asm
index 715e41847..74d476dec 100644
--- a/engine/cgb_layouts.asm
+++ b/engine/cgb_layouts.asm
@@ -68,21 +68,21 @@ Predef_LoadSGBLayoutCGB: ; 8d59
_CGB_BattleGrayscale: ; 8db8
ld hl, PalPacket_9c66 + 1
- ld de, UnknBGPals
+ ld de, wBGPals1
ld c, 4
call CopyPalettes
ld hl, PalPacket_9c66 + 1
- ld de, UnknBGPals palette PAL_BATTLE_BG_EXP
+ ld de, wBGPals1 palette PAL_BATTLE_BG_EXP
ld c, 4
call CopyPalettes
ld hl, PalPacket_9c66 + 1
- ld de, UnknOBPals
+ ld de, wOBPals1
ld c, 2
call CopyPalettes
jr _CGB_FinishBattleScreenLayout
_CGB_BattleColors: ; 8ddb
- ld de, UnknBGPals
+ ld de, wBGPals1
call GetBattlemonBackpicPalettePointer
push hl
call LoadPalette_White_Col1_Col2_Black ; PAL_BATTLE_BG_PLAYER
@@ -107,7 +107,7 @@ _CGB_BattleColors: ; 8ddb
call LoadPalette_White_Col1_Col2_Black ; PAL_BATTLE_BG_PLAYER_HP
ld hl, ExpBarPalette
call LoadPalette_White_Col1_Col2_Black ; PAL_BATTLE_BG_EXP
- ld de, UnknOBPals
+ ld de, wOBPals1
pop hl
call LoadPalette_White_Col1_Col2_Black ; PAL_BATTLE_OB_ENEMY
pop hl
@@ -146,9 +146,9 @@ _CGB_FinishBattleScreenLayout: ; 8e23
ld a, PAL_BATTLE_BG_TEXT
call ByteFill
ld hl, BattleObjectPals
- ld de, UnknOBPals palette PAL_BATTLE_OB_GRAY
+ ld de, wOBPals1 palette PAL_BATTLE_OB_GRAY
ld bc, 6 palettes
- ld a, BANK(UnknOBPals)
+ ld a, BANK(wOBPals1)
call FarCopyWRAM
call ApplyAttrMap
ret
@@ -162,9 +162,9 @@ Mobile_InitPartyMenuBGPal7: ; 8e8b
jr nc, .not_mobile
ld hl, Palette_b309
.not_mobile
- ld de, UnknBGPals palette 7
+ ld de, wBGPals1 palette 7
ld bc, 1 palettes
- ld a, BANK(UnknBGPals)
+ ld a, BANK(wBGPals1)
call FarCopyWRAM
ret
; 8e9f
@@ -175,9 +175,9 @@ InitPartyMenuBGPal0: ; 8e9f
jr nc, .not_mobile
ld hl, Palette_b309
.not_mobile
- ld de, UnknBGPals palette 0
+ ld de, wBGPals1 palette 0
ld bc, 1 palettes
- ld a, BANK(UnknBGPals)
+ ld a, BANK(wBGPals1)
call FarCopyWRAM
ret
; 8eb9
@@ -192,9 +192,9 @@ _CGB_PokegearPals: ; 8eb9
.male
ld hl, MalePokegearPals
.got_pals
- ld de, UnknBGPals
+ ld de, wBGPals1
ld bc, 6 palettes
- ld a, BANK(UnknBGPals)
+ ld a, BANK(wBGPals1)
call FarCopyWRAM
call ApplyPals
ld a, $1
@@ -203,7 +203,7 @@ _CGB_PokegearPals: ; 8eb9
; 8edb
_CGB_StatsScreenHPPals: ; 8edb
- ld de, UnknBGPals
+ ld de, wBGPals1
ld a, [wCurHPPal]
ld l, a
ld h, $0
@@ -219,9 +219,9 @@ _CGB_StatsScreenHPPals: ; 8edb
ld hl, ExpBarPalette
call LoadPalette_White_Col1_Col2_Black ; exp palette
ld hl, StatsScreenPagePals
- ld de, UnknBGPals palette 3
+ ld de, wBGPals1 palette 3
ld bc, 3 palettes ; pink, green, and blue page palettes
- ld a, BANK(UnknBGPals)
+ ld a, BANK(wBGPals1)
call FarCopyWRAM
call WipeAttrMap
@@ -285,7 +285,7 @@ StatsScreenPals: ; 8f6a
; 8f70
_CGB_Pokedex: ; 8f70
- ld de, UnknBGPals
+ ld de, wBGPals1
ld a, $1d
call GetPredefPal
call LoadHLPaletteIntoDE ; dex interface palette
@@ -307,9 +307,9 @@ _CGB_Pokedex: ; 8f70
call FillBoxCGB
call InitPartyMenuOBPals
ld hl, .PokedexCursorPalette
- ld de, UnknOBPals palette 7 ; green cursor palette
+ ld de, wOBPals1 palette 7 ; green cursor palette
ld bc, 1 palettes
- ld a, BANK(UnknOBPals)
+ ld a, BANK(wOBPals1)
call FarCopyWRAM
call ApplyAttrMap
call ApplyPals
@@ -332,7 +332,7 @@ _CGB_Pokedex: ; 8f70
; 8fca
_CGB_BillsPC: ; 8fca
- ld de, UnknBGPals
+ ld de, wBGPals1
ld a, $1d
call GetPredefPal
call LoadHLPaletteIntoDE
@@ -392,7 +392,7 @@ _CGB_BillsPC: ; 8fca
; 903e
_CGB_PokedexUnownMode: ; 903e
- ld de, UnknBGPals
+ ld de, wBGPals1
ld a, $1d
call GetPredefPal
call LoadHLPaletteIntoDE
@@ -414,9 +414,9 @@ _CGB_PokedexUnownMode: ; 903e
_CGB_SlotMachine: ; 906e
ld hl, SlotMachinePals
- ld de, UnknBGPals
+ ld de, wBGPals1
ld bc, 16 palettes
- ld a, BANK(UnknBGPals)
+ ld a, BANK(wBGPals1)
call FarCopyWRAM
call WipeAttrMap
hlcoord 0, 2, AttrMap
@@ -470,7 +470,7 @@ _CGB06: ; 90f8
ld hl, PalPacket_9ca6 + 1
call CopyFourPalettes
call WipeAttrMap
- ld de, UnknOBPals
+ ld de, wOBPals1
ld a, $3c
call GetPredefPal
call LoadHLPaletteIntoDE
@@ -504,12 +504,12 @@ _CGB07: ; 9122
.Function9133: ; 9133
ld hl, .Palette_914e
- ld de, UnknBGPals
+ ld de, wBGPals1
call LoadHLPaletteIntoDE
ld hl, .Palette_9156
- ld de, UnknOBPals
+ ld de, wOBPals1
ld bc, 2 palettes
- ld a, BANK(UnknOBPals)
+ ld a, BANK(wOBPals1)
call FarCopyWRAM
call WipeAttrMap
ret
@@ -534,12 +534,12 @@ _CGB07: ; 9122
; 9166
.Function9166: ; 9166
- ld de, UnknBGPals
+ ld de, wBGPals1
ld a, $38
call GetPredefPal
call LoadHLPaletteIntoDE
- ld de, UnknOBPals
+ ld de, wOBPals1
ld a, $39
call GetPredefPal
call LoadHLPaletteIntoDE
@@ -550,7 +550,7 @@ _CGB07: ; 9122
.Function9180: ; 9180
ld hl, PalPacket_9c36 + 1
call CopyFourPalettes
- ld de, UnknOBPals
+ ld de, wOBPals1
ld a, $3a
call GetPredefPal
call LoadHLPaletteIntoDE
@@ -560,9 +560,9 @@ _CGB07: ; 9122
_CGB11: ; 9195
ld hl, Palettes_b789
- ld de, UnknBGPals
+ ld de, wBGPals1
ld bc, 5 palettes
- ld a, BANK(UnknBGPals)
+ ld a, BANK(wBGPals1)
call FarCopyWRAM
call ApplyPals
call WipeAttrMap
@@ -572,9 +572,9 @@ _CGB11: ; 9195
_CGB_Diploma: ; 91ad
ld hl, DiplomaPalettes
- ld de, UnknBGPals
+ ld de, wBGPals1
ld bc, 16 palettes
- ld a, BANK(UnknBGPals)
+ ld a, BANK(wBGPals1)
call FarCopyWRAM
ld hl, PalPacket_9cb6 + 1
@@ -602,7 +602,7 @@ _CGB_PartyMenu: ; 91d1
; 91e4
_CGB_Evolution: ; 91e4
- ld de, UnknBGPals
+ ld de, wBGPals1
ld a, c
and a
jr z, .pokemon
@@ -622,9 +622,9 @@ _CGB_Evolution: ; 91e4
call GetPlayerOrMonPalettePointer
call LoadPalette_White_Col1_Col2_Black
ld hl, BattleObjectPals
- ld de, UnknOBPals palette PAL_BATTLE_OB_GRAY
+ ld de, wOBPals1 palette PAL_BATTLE_OB_GRAY
ld bc, 6 palettes
- ld a, BANK(UnknOBPals)
+ ld a, BANK(wOBPals1)
call FarCopyWRAM
.got_palette
@@ -638,14 +638,14 @@ _CGB_Evolution: ; 91e4
_CGB0c: ; 9228
ld hl, Palettes_b6f1
- ld de, UnknBGPals
+ ld de, wBGPals1
ld bc, 5 palettes
- ld a, BANK(UnknBGPals)
+ ld a, BANK(wBGPals1)
call FarCopyWRAM
ld hl, Palettes_b719
- ld de, UnknOBPals
+ ld de, wOBPals1
ld bc, 2 palettes
- ld a, BANK(UnknOBPals)
+ ld a, BANK(wOBPals1)
call FarCopyWRAM
ld a, SCGB_DIPLOMA
ld [SGBPredef], a
@@ -666,15 +666,15 @@ _CGB0d: ; 9251
_CGB_UnownPuzzle: ; 925e
ld hl, PalPacket_9bc6 + 1
call CopyFourPalettes
- ld de, UnknOBPals
+ ld de, wOBPals1
ld a, $4c
call GetPredefPal
call LoadHLPaletteIntoDE
ld a, [rSVBK]
push af
- ld a, BANK(UnknOBPals)
+ ld a, BANK(wOBPals1)
ld [rSVBK], a
- ld hl, UnknOBPals
+ ld hl, wOBPals1
ld a, $1f
ld [hli], a
ld a, $0
@@ -687,7 +687,7 @@ _CGB_UnownPuzzle: ; 925e
; 9289
_CGB_TrainerCard: ; 9289
- ld de, UnknBGPals
+ ld de, wBGPals1
xor a ; CHRIS
call GetTrainerPalettePointer
call LoadPalette_White_Col1_Col2_Black
@@ -793,7 +793,7 @@ _CGB_TrainerCard: ; 9289
; 9373
_CGB_MoveList: ; 9373
- ld de, UnknBGPals
+ ld de, wBGPals1
ld a, $10
call GetPredefPal
call LoadHLPaletteIntoDE
@@ -829,7 +829,7 @@ _CGB0f: ; 93a6
; 93ba
_CGB_PokedexSearchOption: ; 93ba
- ld de, UnknBGPals
+ ld de, wBGPals1
ld a, $1d
call GetPredefPal
call LoadHLPaletteIntoDE
@@ -858,9 +858,9 @@ _CGB_PackPals: ; 93d3
ld hl, .ChrisPackPals
.got_gender
- ld de, UnknBGPals
+ ld de, wBGPals1
ld bc, 8 palettes ; 6 palettes?
- ld a, BANK(UnknBGPals)
+ ld a, BANK(wBGPals1)
call FarCopyWRAM
call WipeAttrMap
hlcoord 0, 0, AttrMap
@@ -953,15 +953,15 @@ _CGB13: ; 94d0
; 94fa
_CGB_GamefreakLogo: ; 94fa
- ld de, UnknBGPals
+ ld de, wBGPals1
ld a, $4e
call GetPredefPal
call LoadHLPaletteIntoDE
ld hl, .Palette
- ld de, UnknOBPals
+ ld de, wOBPals1
call LoadHLPaletteIntoDE
ld hl, .Palette
- ld de, UnknOBPals palette 1
+ ld de, wOBPals1 palette 1
call LoadHLPaletteIntoDE
call WipeAttrMap
call ApplyAttrMap
@@ -977,7 +977,7 @@ _CGB_GamefreakLogo: ; 94fa
; 9529
_CGB_PlayerOrMonFrontpicPals: ; 9529
- ld de, UnknBGPals
+ ld de, wBGPals1
ld a, [CurPartySpecies]
ld bc, TempMonDVs
call GetPlayerOrMonPalettePointer
@@ -989,7 +989,7 @@ _CGB_PlayerOrMonFrontpicPals: ; 9529
; 9542
_CGB1e: ; 9542
- ld de, UnknBGPals
+ ld de, wBGPals1
ld a, [CurPartySpecies]
call GetMonPalettePointer_
call LoadPalette_White_Col1_Col2_Black
@@ -1002,11 +1002,11 @@ _CGB_TradeTube: ; 9555
ld hl, PalPacket_9cc6 + 1
call CopyFourPalettes
ld hl, PartyMenuOBPals
- ld de, UnknOBPals
+ ld de, wOBPals1
ld bc, 1 palettes
- ld a, BANK(UnknOBPals)
+ ld a, BANK(wOBPals1)
call FarCopyWRAM
- ld de, UnknOBPals palette 7
+ ld de, wOBPals1 palette 7
ld a, $1c
call GetPredefPal
call LoadHLPaletteIntoDE
@@ -1015,7 +1015,7 @@ _CGB_TradeTube: ; 9555
; 9578
_CGB_TrainerOrMonFrontpicPals: ; 9578
- ld de, UnknBGPals
+ ld de, wBGPals1
ld a, [CurPartySpecies]
ld bc, TempMonDVs
call GetFrontpicPalettePointer
@@ -1028,9 +1028,9 @@ _CGB_TrainerOrMonFrontpicPals: ; 9578
_CGB_MysteryGift: ; 9591
ld hl, .Palettes
- ld de, UnknBGPals
+ ld de, wBGPals1
ld bc, 2 palettes
- ld a, BANK(UnknBGPals)
+ ld a, BANK(wBGPals1)
call FarCopyWRAM
call ApplyPals
call WipeAttrMap
diff --git a/engine/color.asm b/engine/color.asm
index 262bccbbb..3ffd5d0f4 100644
--- a/engine/color.asm
+++ b/engine/color.asm
@@ -142,13 +142,13 @@ Function8b07:
ret z
; CGB only
ld hl, .BGPal
- ld de, UnknBGPals
+ ld de, wBGPals1
ld bc, 1 palettes
ld a, $5
call FarCopyWRAM
ld hl, .OBPal
- ld de, UnknOBPals
+ ld de, wOBPals1
ld bc, 1 palettes
ld a, $5
call FarCopyWRAM
@@ -191,7 +191,7 @@ Function8b4d:
jp PushSGBPals_
.cgb
- ld de, UnknOBPals
+ ld de, wOBPals1
ld a, $3b
call GetPredefPal
jp LoadHLPaletteIntoDE
@@ -207,7 +207,7 @@ Function8b67:
jp PushSGBPals_
.cgb
- ld de, UnknOBPals
+ ld de, wOBPals1
ld a, $3c
call GetPredefPal
jp LoadHLPaletteIntoDE
@@ -239,7 +239,7 @@ Function8b81:
jp PushSGBPals_
.cgb
- ld de, UnknOBPals
+ ld de, wOBPals1
ld a, c
call GetMonPalettePointer_
call LoadPalette_White_Col1_Col2_Black
@@ -265,7 +265,7 @@ LoadMonPaletteAsNthBGPal:
got_palette_pointer_8bd7
push hl
- ld hl, UnknBGPals
+ ld hl, wBGPals1
ld de, 1 palettes
.loop
and a
@@ -327,7 +327,7 @@ ApplyMonOrTrainerPals:
call GetTrainerPalettePointer
.load_palettes
- ld de, UnknBGPals
+ ld de, wBGPals1
call LoadPalette_White_Col1_Col2_Black
call WipeAttrMap
call ApplyAttrMap
@@ -345,11 +345,11 @@ ApplyHPBarPals:
ret
.Enemy:
- ld de, BGPals palette PAL_BATTLE_BG_ENEMY_HP + 2
+ ld de, wBGPals2 palette PAL_BATTLE_BG_ENEMY_HP + 2
jr .okay
.Player:
- ld de, BGPals palette PAL_BATTLE_BG_PLAYER_HP + 2
+ ld de, wBGPals2 palette PAL_BATTLE_BG_PLAYER_HP + 2
.okay
ld l, c
@@ -397,11 +397,11 @@ LoadStatsScreenPals:
ld a, $5
ld [rSVBK], a
ld a, [hli]
- ld [UnknBGPals palette 0], a
- ld [UnknBGPals palette 2], a
+ ld [wBGPals1 palette 0], a
+ ld [wBGPals1 palette 2], a
ld a, [hl]
- ld [UnknBGPals palette 0 + 1], a
- ld [UnknBGPals palette 2 + 1], a
+ ld [wBGPals1 palette 0 + 1], a
+ ld [wBGPals1 palette 2 + 1], a
pop af
ld [rSVBK], a
call ApplyPals
@@ -441,7 +441,7 @@ LoadMailPalettes:
ret
.cgb
- ld de, UnknBGPals
+ ld de, wBGPals1
ld bc, 1 palettes
ld a, $5
call FarCopyWRAM
@@ -458,7 +458,7 @@ INCLUDE "engine/cgb_layouts.asm"
Function95f0:
; XXX
ld hl, .Palette
- ld de, UnknBGPals
+ ld de, wBGPals1
ld bc, 1 palettes
ld a, $5
call FarCopyWRAM
@@ -474,7 +474,7 @@ Function95f0:
RGB 00, 03, 19
CopyFourPalettes:
- ld de, UnknBGPals
+ ld de, wBGPals1
ld c, $4
CopyPalettes:
@@ -575,7 +575,7 @@ ResetBGPals:
ld a, $5
ld [rSVBK], a
- ld hl, UnknBGPals
+ ld hl, wBGPals1
ld c, 1 palettes
.loop
ld a, $ff
@@ -608,8 +608,8 @@ WipeAttrMap:
ret
ApplyPals:
- ld hl, UnknBGPals
- ld de, BGPals
+ ld hl, wBGPals1
+ ld de, wBGPals2
ld bc, 16 palettes
ld a, $5
call FarCopyWRAM
@@ -686,7 +686,7 @@ CGB_ApplyPartyMenuHPPals: ; 96f3
InitPartyMenuOBPals:
ld hl, PartyMenuOBPals
- ld de, UnknOBPals
+ ld de, wOBPals1
ld bc, 2 palettes
ld a, $5
call FarCopyWRAM
@@ -759,7 +759,7 @@ Function9779: mobile
dec c
jr nz, .loop
ld hl, BattleObjectPals
- ld de, UnknOBPals palette 2
+ ld de, wOBPals1 palette 2
ld bc, 2 palettes
ld a, $5
call FarCopyWRAM
@@ -932,9 +932,9 @@ InitCGBPals::
push af
ld a, $5
ld [rSVBK], a
- ld hl, UnknBGPals
+ ld hl, wBGPals1
call .LoadWhitePals
- ld hl, BGPals
+ ld hl, wBGPals2
call .LoadWhitePals
pop af
ld [rSVBK], a
@@ -1253,7 +1253,7 @@ LoadMapPals:
push af
ld a, $5
ld [rSVBK], a
- ld hl, UnknBGPals
+ ld hl, wBGPals1
ld b, 8
.outer_loop
ld a, [de] ; lookup index for TilesetBGPalette
@@ -1289,9 +1289,9 @@ LoadMapPals:
ld bc, 8 palettes
ld hl, MapObjectPals
call AddNTimes
- ld de, UnknOBPals
+ ld de, wOBPals1
ld bc, 8 palettes
- ld a, BANK(UnknOBPals)
+ ld a, BANK(wOBPals1)
call FarCopyWRAM
ld a, [wEnvironment]
@@ -1316,7 +1316,7 @@ rept 4
inc hl
endr
.morn_day
- ld de, UnknBGPals palette PAL_BG_ROOF + 2
+ ld de, wBGPals1 palette PAL_BG_ROOF + 2
ld bc, 4
ld a, $5
call FarCopyWRAM
diff --git a/engine/credits.asm b/engine/credits.asm
index 051729531..3dddb4126 100644
--- a/engine/credits.asm
+++ b/engine/credits.asm
@@ -520,20 +520,20 @@ GetCreditsPalette: ; 109b2c
; Update the first three colors in both palette buffers.
push af
push hl
- add LOW(UnknBGPals)
+ add LOW(wBGPals1)
ld e, a
ld a, 0
- adc HIGH(UnknBGPals)
+ adc HIGH(wBGPals1)
ld d, a
ld bc, 24
call CopyBytes
pop hl
pop af
- add LOW(BGPals)
+ add LOW(wBGPals2)
ld e, a
ld a, 0
- adc HIGH(BGPals)
+ adc HIGH(wBGPals2)
ld d, a
ld bc, 24
call CopyBytes
diff --git a/engine/crystal_colors.asm b/engine/crystal_colors.asm
index 8410caa0e..5d2ba236c 100755
--- a/engine/crystal_colors.asm
+++ b/engine/crystal_colors.asm
@@ -54,15 +54,15 @@ MG_Mobile_Layout_WipeAttrMap: ; 49346 (12:5346)
ret
MG_Mobile_Layout_LoadPals: ; 49351 (12:5351)
- ld de, UnknBGPals
+ ld de, wBGPals1
ld hl, Palette_493e1
ld bc, 5 palettes
- ld a, BANK(UnknBGPals)
+ ld a, BANK(wBGPals1)
call FarCopyWRAM
- ld de, UnknBGPals palette PAL_BG_TEXT
+ ld de, wBGPals1 palette PAL_BG_TEXT
ld hl, Palette_TextBG7
ld bc, 1 palettes
- ld a, BANK(UnknBGPals)
+ ld a, BANK(wBGPals1)
call FarCopyWRAM
ret
@@ -118,9 +118,9 @@ INCLUDE "data/palettes/mg_mobile.pal"
LoadOW_BGPal7:: ; 49409
ld hl, Palette_TextBG7
- ld de, UnknBGPals palette PAL_BG_TEXT
+ ld de, wBGPals1 palette PAL_BG_TEXT
ld bc, 1 palettes
- ld a, BANK(UnknBGPals)
+ ld a, BANK(wBGPals1)
call FarCopyWRAM
ret
; 49418
@@ -131,19 +131,19 @@ INCLUDE "data/palettes/overworld/bg_text.pal"
Function49420:: ; 49420 (12:5420)
ld hl, MansionPalette4
- ld de, UnknBGPals palette PAL_BG_ROOF
+ ld de, wBGPals1 palette PAL_BG_ROOF
ld bc, 1 palettes
- ld a, BANK(UnknBGPals)
+ ld a, BANK(wBGPals1)
call FarCopyWRAM
ret
; 4942f (12:542f)
MG_Mobile_Layout01: ; 4942f
call MG_Mobile_Layout_LoadPals
- ld de, UnknBGPals palette PAL_BG_TEXT
+ ld de, wBGPals1 palette PAL_BG_TEXT
ld hl, .Palette_49478
ld bc, 1 palettes
- ld a, BANK(UnknBGPals)
+ ld a, BANK(wBGPals1)
call FarCopyWRAM
call MG_Mobile_Layout_WipeAttrMap
hlcoord 0, 0, AttrMap
@@ -208,17 +208,17 @@ INCLUDE "tilesets/special_palettes.asm"
MG_Mobile_Layout02: ; 49706
ld hl, .Palette_49732
- ld de, UnknBGPals
+ ld de, wBGPals1
ld bc, 1 palettes
- ld a, BANK(UnknBGPals)
+ ld a, BANK(wBGPals1)
call FarCopyWRAM
farcall ApplyPals
call MG_Mobile_Layout_WipeAttrMap
farcall ApplyAttrMap
ld hl, .Palette_4973a
- ld de, UnknOBPals
+ ld de, wOBPals1
ld bc, 1 palettes
- ld a, BANK(UnknOBPals)
+ ld a, BANK(wOBPals1)
call FarCopyWRAM
ret
; 49732
@@ -239,7 +239,7 @@ MG_Mobile_Layout02: ; 49706
Function49742: ; 49742
ld hl, .Palette_49757
- ld de, UnknBGPals
+ ld de, wBGPals1
ld bc, 8 palettes
ld a, $5
call FarCopyWRAM
@@ -305,9 +305,9 @@ _InitMG_Mobile_LinkTradePalMap: ; 49797
LoadTradeRoomBGPals: ; 49811
ld hl, TradeRoomPalette
- ld de, UnknBGPals palette PAL_BG_GREEN
+ ld de, wBGPals1 palette PAL_BG_GREEN
ld bc, 6 palettes
- ld a, BANK(UnknBGPals)
+ ld a, BANK(wBGPals1)
call FarCopyWRAM
farcall ApplyPals
ret
diff --git a/engine/debug.asm b/engine/debug.asm
index dee9b035d..509205d1e 100755
--- a/engine/debug.asm
+++ b/engine/debug.asm
@@ -158,7 +158,7 @@ Function819a7: ; 819a7
ld a, $5
ld [rSVBK], a
ld hl, Palette_819f4
- ld de, BGPals
+ ld de, wBGPals2
ld bc, 16 palettes
call CopyBytes
ld a, $80
@@ -438,7 +438,7 @@ Function81c33: ; 81c33
push af
ld a, $5
ld [rSVBK], a
- ld hl, BGPals
+ ld hl, wBGPals2
ld de, wc608
ld c, $1
call Function81ee3
@@ -1153,7 +1153,7 @@ Function8220f: ; 8220f
add hl, hl
add hl, hl
add hl, hl
- ld de, UnknBGPals
+ ld de, wBGPals1
add hl, de
ld de, wc608
ld bc, 8
@@ -1200,7 +1200,7 @@ Function82236: ; 82236
push af
ld a, $5
ld [rSVBK], a
- ld hl, BGPals
+ ld hl, wBGPals2
ld a, [wcf64]
ld bc, 1 palettes
call AddNTimes
@@ -1230,7 +1230,7 @@ Function822a3: ; 822a3
push af
ld a, $5
ld [rSVBK], a
- ld hl, BGPals
+ ld hl, wBGPals2
ld a, [wcf64]
ld bc, 1 palettes
call AddNTimes
diff --git a/engine/events/heal_machine_anim.asm b/engine/events/heal_machine_anim.asm
index b51976d22..493330e58 100755
--- a/engine/events/heal_machine_anim.asm
+++ b/engine/events/heal_machine_anim.asm
@@ -158,7 +158,7 @@ INCBIN "gfx/overworld/heal_machine.2bpp"
.cgb
ld hl, .palettes
- ld de, OBPals palette PAL_OW_TREE
+ ld de, wOBPals2 palette PAL_OW_TREE
ld bc, 1 palettes
ld a, $5
call FarCopyWRAM
@@ -201,7 +201,7 @@ INCBIN "gfx/overworld/heal_machine.2bpp"
ld a, $5
ld [rSVBK], a
- ld hl, OBPals palette PAL_OW_TREE
+ ld hl, wOBPals2 palette PAL_OW_TREE
ld a, [hli]
ld e, a
ld a, [hli]
diff --git a/engine/events/poisonstep_pals.asm b/engine/events/poisonstep_pals.asm
index 9562ecb67..498ae8f18 100644
--- a/engine/events/poisonstep_pals.asm
+++ b/engine/events/poisonstep_pals.asm
@@ -28,7 +28,7 @@ LoadPoisonBGPals: ; cbcdd
push af
ld a, $5
ld [rSVBK], a
- ld hl, BGPals
+ ld hl, wBGPals2
ld c, 4 palettes
.loop
; RGB 28, 21, 31
diff --git a/engine/init_gender.asm b/engine/init_gender.asm
index bb6ce3736..588709b88 100755
--- a/engine/init_gender.asm
+++ b/engine/init_gender.asm
@@ -88,7 +88,7 @@ InitGenderScreen: ; 48e14 (12:4e14)
LoadGenderScreenPal: ; 48e47 (12:4e47)
ld hl, .Palette
- ld de, UnknBGPals
+ ld de, wBGPals1
ld bc, 1 palettes
ld a, $5
call FarCopyWRAM
diff --git a/engine/init_hof_credits.asm b/engine/init_hof_credits.asm
index 99d142236..8e3db75eb 100644
--- a/engine/init_hof_credits.asm
+++ b/engine/init_hof_credits.asm
@@ -43,7 +43,7 @@ InitDisplayForRedCredits: ; 4e8c2
ld bc, SCREEN_WIDTH * SCREEN_HEIGHT
xor a
call ByteFill
- ld hl, UnknBGPals
+ ld hl, wBGPals1
ld c, 4 tiles
.load_white_palettes
ld a, LOW(palred 31 + palgreen 31 + palblue 31)
diff --git a/engine/pokedex.asm b/engine/pokedex.asm
index aa540e9c6..5dc3dc2a7 100644
--- a/engine/pokedex.asm
+++ b/engine/pokedex.asm
@@ -2350,7 +2350,7 @@ Pokedex_BlackOutBG: ; 41401 (10:5401)
push af
ld a, $5
ld [rSVBK], a
- ld hl, UnknBGPals
+ ld hl, wBGPals1
ld bc, 8 palettes
xor a
call ByteFill
diff --git a/engine/timeofdaypals.asm b/engine/timeofdaypals.asm
index 56a874264..0b1ea71a2 100644
--- a/engine/timeofdaypals.asm
+++ b/engine/timeofdaypals.asm
@@ -42,7 +42,7 @@ _TimeOfDayPals:: ; 8c011
ld [TimeOfDayPal], a
; save bg palette 7
- ld hl, UnknBGPals palette PAL_BG_TEXT
+ ld hl, wBGPals1 palette PAL_BG_TEXT
; save wram bank
ld a, [rSVBK]
@@ -73,7 +73,7 @@ _TimeOfDayPals:: ; 8c011
; restore bg palette 7
- ld hl, UnknOBPals - 1 ; last byte in UnknBGPals
+ ld hl, wOBPals1 - 1 ; last byte in wBGPals1
; save wram bank
ld a, [rSVBK]
@@ -176,12 +176,12 @@ FillWhiteBGColor: ; 8c0c1
ld a, $5
ld [rSVBK], a
- ld hl, UnknBGPals
+ ld hl, wBGPals1
ld a, [hli]
ld e, a
ld a, [hli]
ld d, a
- ld hl, UnknBGPals + 1 palettes
+ ld hl, wBGPals1 + 1 palettes
ld c, 6
.loop
ld a, e
diff --git a/engine/title.asm b/engine/title.asm
index 4a6dc6fa9..2380cfedf 100644
--- a/engine/title.asm
+++ b/engine/title.asm
@@ -144,12 +144,12 @@ _TitleScreen: ; 10ed67
; Update palette colors
ld hl, TitleScreenPalettes
- ld de, UnknBGPals
+ ld de, wBGPals1
ld bc, 16 palettes
call CopyBytes
ld hl, TitleScreenPalettes
- ld de, BGPals
+ ld de, wBGPals2
ld bc, 16 palettes
call CopyBytes
@@ -220,7 +220,7 @@ _TitleScreen: ; 10ed67
ld [hBGMapMode], a
xor a
- ld [UnknBGPals + 2], a
+ ld [wBGPals1 + 2], a
; Play starting sound effect
call SFXChannelsOff
@@ -231,7 +231,7 @@ _TitleScreen: ; 10ed67
; 10eea7
SuicuneFrameIterator: ; 10eea7
- ld hl, UnknBGPals + 2
+ ld hl, wBGPals1 + 2
ld a, [hl]
ld c, a
inc [hl]
diff --git a/engine/unused_title.asm b/engine/unused_title.asm
index 650e17863..f0b59b527 100644
--- a/engine/unused_title.asm
+++ b/engine/unused_title.asm
@@ -67,22 +67,22 @@ UnusedTitleScreen: ; 10c000
ld [rSVBK], a
ld hl, UnusedTitleBG_Palettes
- ld de, UnknBGPals
+ ld de, wBGPals1
ld bc, 8 palettes
call CopyBytes
ld hl, UnusedTitleFG_Palettes
- ld de, UnknOBPals
+ ld de, wOBPals1
ld bc, 8 palettes
call CopyBytes
ld hl, UnusedTitleBG_Palettes
- ld de, BGPals
+ ld de, wBGPals2
ld bc, 8 palettes
call CopyBytes
ld hl, UnusedTitleFG_Palettes
- ld de, OBPals
+ ld de, wOBPals2
ld bc, 8 palettes
call CopyBytes
diff --git a/home.asm b/home.asm
index 4c59d1d1a..8e4b3b171 100644
--- a/home.asm
+++ b/home.asm
@@ -680,11 +680,11 @@ ClearPalettes:: ; 3317
ld a, [rSVBK]
push af
- ld a, BANK(BGPals)
+ ld a, BANK(wBGPals2)
ld [rSVBK], a
-; Fill BGPals and OBPals with $ffff (white)
- ld hl, BGPals
+; Fill wBGPals2 and wOBPals2 with $ffff (white)
+ ld hl, wBGPals2
ld bc, 16 palettes
ld a, $ff
call ByteFill
diff --git a/mobile/fixed_words.asm b/mobile/fixed_words.asm
index b3f33fafe..a1ddb5ad2 100755
--- a/mobile/fixed_words.asm
+++ b/mobile/fixed_words.asm
@@ -2921,7 +2921,7 @@ Function11d323: ; 11d323
ld a, $5
ld [rSVBK], a
ld hl, Palette_11d33a
- ld de, UnknBGPals
+ ld de, wBGPals1
ld bc, 16 palettes
call CopyBytes
pop af
diff --git a/mobile/mobile_22.asm b/mobile/mobile_22.asm
index b82280482..9180c29e0 100644
--- a/mobile/mobile_22.asm
+++ b/mobile/mobile_22.asm
@@ -631,7 +631,7 @@ Function8949c: ; 8949c
ld a, 5
ld [rSVBK], a
ld hl, Palette_894b3
- ld de, UnknBGPals palette 7
+ ld de, wBGPals1 palette 7
ld bc, 1 palettes
call CopyBytes
pop af
@@ -682,11 +682,11 @@ Function894dc: ; 894dc
ld a, [hli]
ld h, [hl]
ld l, a
- ld de, UnknBGPals
+ ld de, wBGPals1
ld bc, 3 palettes
call CopyBytes
ld hl, .Pals345
- ld de, UnknBGPals + 3 palettes
+ ld de, wBGPals1 + 3 palettes
ld bc, 3 palettes
call CopyBytes
@@ -2161,7 +2161,7 @@ Function89d0d: ; 89d0d (22:5d0d)
ld [rSVBK], a
ld c, 8
- ld de, UnknBGPals
+ ld de, wBGPals1
.loop
push bc
ld hl, .Palette1
@@ -2172,7 +2172,7 @@ Function89d0d: ; 89d0d (22:5d0d)
jr nz, .loop
ld hl, .Palette2
- ld de, UnknBGPals + 2 palettes
+ ld de, wBGPals1 + 2 palettes
ld bc, 1 palettes
call CopyBytes
@@ -2394,7 +2394,7 @@ Function89e9a: ; 89e9a (22:5e9a)
ld a, $5
ld [rSVBK], a
ld hl, Palette_89eb1
- ld de, UnknBGPals palette 5
+ ld de, wBGPals1 palette 5
ld bc, 1 palettes
call CopyBytes
pop af
@@ -3399,15 +3399,15 @@ Function8a5b6: ; 8a5b6 (22:65b6)
ld a, $5
ld [rSVBK], a
ld hl, Palette_8a5e5
- ld de, UnknBGPals + 4 palettes
+ ld de, wBGPals1 + 4 palettes
ld bc, 3 palettes
call CopyBytes
ld hl, Palette_8a5fd
- ld de, UnknOBPals
+ ld de, wOBPals1
ld bc, 1 palettes
call CopyBytes
ld hl, Palette_8a605
- ld de, UnknOBPals + 1 palettes
+ ld de, wOBPals1 + 1 palettes
ld bc, 1 palettes
call CopyBytes
pop af
@@ -3452,7 +3452,7 @@ Function8a60d: ; 8a60d
ld a, $5
ld [rSVBK], a
ld hl, Palette_8a624
- ld de, UnknOBPals
+ ld de, wOBPals1
ld bc, 1 palettes
call CopyBytes
pop af
diff --git a/mobile/mobile_22_2.asm b/mobile/mobile_22_2.asm
index a1394bf44..37b3d60b8 100644
--- a/mobile/mobile_22_2.asm
+++ b/mobile/mobile_22_2.asm
@@ -620,7 +620,7 @@ Function8b6bb: ; 8b6bb
ld a, $5
ld [rSVBK], a
ld hl, Palette_8b6d5
- ld de, UnknBGPals
+ ld de, wBGPals1
ld bc, 3 palettes
call CopyBytes
pop af
diff --git a/mobile/mobile_40.asm b/mobile/mobile_40.asm
index 0d29239e0..84be87ce4 100644
--- a/mobile/mobile_40.asm
+++ b/mobile/mobile_40.asm
@@ -6853,7 +6853,7 @@ Function102dd3: ; 102dd3
Function102dec: ; 102dec
ld hl, Palettes_1032e2
- ld de, UnknOBPals
+ ld de, wOBPals1
ld bc, 4 palettes
ld a, $05
call FarCopyWRAM
diff --git a/mobile/mobile_42.asm b/mobile/mobile_42.asm
index 82158c1c7..53adb8fe0 100644
--- a/mobile/mobile_42.asm
+++ b/mobile/mobile_42.asm
@@ -836,7 +836,7 @@ MobileTradeAnim_02: ; 108638
ld a, $5
ld [rSVBK], a
ld hl, Palette_109107
- ld de, UnknBGPals
+ ld de, wBGPals1
ld bc, 8 palettes
call CopyBytes
pop af
@@ -882,7 +882,7 @@ MobileTradeAnim_10: ; 108689
ld a, $5
ld [rSVBK], a
ld hl, Palette_109107
- ld de, UnknBGPals
+ ld de, wBGPals1
ld bc, 8 palettes
call CopyBytes
pop af
@@ -926,7 +926,7 @@ MobileTradeAnim_11: ; 1086f4
ld a, $5
ld [rSVBK], a
ld hl, Palette_109107
- ld de, UnknBGPals
+ ld de, wBGPals1
ld bc, 8 palettes
call CopyBytes
pop af
@@ -946,7 +946,7 @@ MobileTradeAnim_GiveTrademon1: ; 108763
ld de, SFX_GIVE_TRADEMON
call PlaySFX
ld c, 40
- ld hl, BGPals palette 6
+ ld hl, wBGPals2 palette 6
call Function1082f0
call Function108af4
.loop
@@ -1010,7 +1010,7 @@ MobileTradeAnim_GiveTrademon1: ; 108763
MobileTradeAnim_GiveTrademon2: ; 1087cf
ld c, 40
- ld hl, BGPals + 1 palettes
+ ld hl, wBGPals2 + 1 palettes
call Function1082f0
call Function108af4
call Function108b5a
@@ -1109,12 +1109,12 @@ MobileTradeAnim_GetTrademon1: ; 108863
MobileTradeAnim_GetTrademon2: ; 108894
ld c, 20
- ld hl, BGPals + 1 palettes
+ ld hl, wBGPals2 + 1 palettes
call Function1082fa
ld de, SFX_GIVE_TRADEMON
call PlaySFX
ld c, 20
- ld hl, BGPals + 1 palettes
+ ld hl, wBGPals2 + 1 palettes
call Function1082fa
call Function108af4
.asm_1088ad
@@ -1178,7 +1178,7 @@ MobileTradeAnim_GetTrademon2: ; 108894
MobileTradeAnim_GetTrademon3: ; 10890a
ld c, 40
- ld hl, BGPals palette 6
+ ld hl, wBGPals2 palette 6
call Function1082f0
call Function108af4
call GetMobileTradeAnimByte
@@ -1449,22 +1449,22 @@ Function108af4: ; 108af4
and $1
jr z, .copy_palette_109147
ld hl, Palette_109187
- ld de, UnknOBPals
+ ld de, wOBPals1
ld bc, 8 palettes
call CopyBytes
ld hl, Palette_109187
- ld de, OBPals
+ ld de, wOBPals2
ld bc, 8 palettes
call CopyBytes
jr .done_copy
.copy_palette_109147
ld hl, Palette_109147
- ld de, UnknOBPals
+ ld de, wOBPals1
ld bc, 8 palettes
call CopyBytes
ld hl, Palette_109147
- ld de, OBPals
+ ld de, wOBPals2
ld bc, 8 palettes
call CopyBytes
@@ -1485,7 +1485,7 @@ Function108b45: ; 108b45
ld a, $5
ld [rSVBK], a
ld de, (31 << 10) + (31 << 5) + 31 ; $7fff
- ld hl, UnknBGPals
+ ld hl, wBGPals1
ld a, e
ld [hli], a
ld d, a
@@ -1501,7 +1501,7 @@ Function108b5a: ; 108b5a
ld a, $5
ld [rSVBK], a
ld de, (15 << 10) + (31 << 5) + 18 ; $3ff2
- ld hl, BGPals + 4 palettes
+ ld hl, wBGPals2 + 4 palettes
ld c, $10
.loop
ld a, e
@@ -1561,7 +1561,7 @@ Function108b98: ; 108b98
.asm_108bad
ld hl, Palette_108b98
.asm_108bb0
- ld de, UnknBGPals + 7 palettes
+ ld de, wBGPals1 + 7 palettes
ld bc, 8 palettes
call CopyBytes
pop af
@@ -1806,7 +1806,7 @@ Function108d07: ; 108d07
ld hl, Palette_1093c7
call AddNTimes
ld a, $5
- ld de, UnknBGPals + 4 palettes
+ ld de, wBGPals1 + 4 palettes
ld bc, 1 palettes
call FarCopyWRAM
ret
diff --git a/mobile/mobile_45.asm b/mobile/mobile_45.asm
index 180ab3758..5fc5eaa7e 100644
--- a/mobile/mobile_45.asm
+++ b/mobile/mobile_45.asm
@@ -7607,7 +7607,7 @@ Function117c4a:
push af
ld a, $5
ld [rSVBK], a
- ld hl, UnknBGPals
+ ld hl, wBGPals1
ld de, 1 palettes
ld c, 8
.loop
diff --git a/mobile/mobile_45_sprite_engine.asm b/mobile/mobile_45_sprite_engine.asm
index 4b1baa2fa..b114e5166 100755
--- a/mobile/mobile_45_sprite_engine.asm
+++ b/mobile/mobile_45_sprite_engine.asm
@@ -523,12 +523,12 @@ Function116294: ; 116294
push af
ld a, $5
ld [rSVBK], a
- ld hl, UnknBGPals palette 6
+ ld hl, wBGPals1 palette 6
ld de, $c320
ld bc, 2 palettes
call CopyBytes
ld hl, Palette_11734e
- ld de, UnknBGPals palette 7
+ ld de, wBGPals1 palette 7
ld bc, 1 palettes
call CopyBytes
call SetPalettes
@@ -550,7 +550,7 @@ Function1162cb: ; 1162cb
ld a, $5
ld [rSVBK], a
ld hl, Palette_11730e
- ld de, UnknOBPals + 2 palettes
+ ld de, wOBPals1 + 2 palettes
ld bc, 6 palettes
call CopyBytes
call SetPalettes
@@ -656,8 +656,8 @@ Function11636e: ; 11636e
push af
ld a, $5
ld [rSVBK], a
- ld hl, BGPals
- ld de, UnknBGPals
+ ld hl, wBGPals2
+ ld de, wBGPals1
ld bc, 8 palettes
call CopyBytes
pop af
diff --git a/mobile/mobile_46.asm b/mobile/mobile_46.asm
index e3503a00c..10a97e426 100755
--- a/mobile/mobile_46.asm
+++ b/mobile/mobile_46.asm
@@ -3449,7 +3449,7 @@ Function119987: ; 119987
ld l, a
ld a, [wcf65]
ld h, a
- ld de, BGPals
+ ld de, wBGPals2
ld a, $22
jp Function119e2b
diff --git a/mobile/mobile_5b.asm b/mobile/mobile_5b.asm
index acedea5b1..f16391871 100755
--- a/mobile/mobile_5b.asm
+++ b/mobile/mobile_5b.asm
@@ -187,7 +187,7 @@ MobileSystemSplashScreen_InitGFX: ; 16c108
; 16c130
.LoadPals: ; 16c130
- ld de, UnknBGPals
+ ld de, wBGPals1
ld hl, UnknownMobilePalettes_16c903
ld bc, 8
ld a, $5
@@ -244,7 +244,7 @@ Function16c943: ; 16c943
ld [rSVBK], a
ld a, $ff
ld bc, 1 palettes
- ld hl, UnknBGPals
+ ld hl, wBGPals1
call ByteFill
pop af
ld [rSVBK], a
@@ -261,7 +261,7 @@ Function16c943: ; 16c943
call Function16cab6
call Function16cabb
ld d, a
- ld hl, UnknBGPals
+ ld hl, wBGPals1
call Function16cab6
call Function16cabb
cp d
@@ -275,7 +275,7 @@ Function16c943: ; 16c943
jr nz, .asm_16c981
.asm_16c988
- ld hl, UnknBGPals
+ ld hl, wBGPals1
call Function16cab6
call Function16cadc
@@ -284,7 +284,7 @@ Function16c943: ; 16c943
call Function16cab6
call Function16cad8
ld d, a
- ld hl, UnknBGPals
+ ld hl, wBGPals1
call Function16cab6
call Function16cad8
cp d
@@ -298,7 +298,7 @@ Function16c943: ; 16c943
jr nz, .asm_16c9a9
.asm_16c9b0
- ld hl, UnknBGPals
+ ld hl, wBGPals1
call Function16cab6
call Function16cb08
@@ -307,7 +307,7 @@ Function16c943: ; 16c943
call Function16cab6
call Function16cac4
ld d, a
- ld hl, UnknBGPals
+ ld hl, wBGPals1
call Function16cab6
call Function16cac4
cp d
@@ -321,7 +321,7 @@ Function16c943: ; 16c943
jr nz, .asm_16c9d1
.asm_16c9d8
- ld hl, UnknBGPals
+ ld hl, wBGPals1
call Function16cab6
call Function16cae8
@@ -371,7 +371,7 @@ Function16ca11: ; 16ca11
ld e, $0
ld a, $0
.asm_16ca28
- ld hl, UnknBGPals
+ ld hl, wBGPals1
call Function16cab6
call Function16cabb
cp $1f
@@ -385,12 +385,12 @@ Function16ca11: ; 16ca11
jr nz, .asm_16ca37
.asm_16ca3f
- ld hl, UnknBGPals
+ ld hl, wBGPals1
call Function16cab6
call Function16cadc
.asm_16ca48
- ld hl, UnknBGPals
+ ld hl, wBGPals1
call Function16cab6
call Function16cad8
cp $1f
@@ -404,12 +404,12 @@ Function16ca11: ; 16ca11
jr nz, .asm_16ca57
.asm_16ca5f
- ld hl, UnknBGPals
+ ld hl, wBGPals1
call Function16cab6
call Function16cb08
.asm_16ca68
- ld hl, UnknBGPals
+ ld hl, wBGPals1
call Function16cab6
call Function16cac4
cp $1f
@@ -423,7 +423,7 @@ Function16ca11: ; 16ca11
jr nz, .asm_16ca77
.asm_16ca7f
- ld hl, UnknBGPals
+ ld hl, wBGPals1
call Function16cab6
call Function16cae8
@@ -682,7 +682,7 @@ Function16cbd1: ; 16cbd1
ld bc, 2
ld hl, Unknown_16cfa3
call AddNTimes
- ld de, UnknBGPals + 1 palettes + 4
+ ld de, wBGPals1 + 1 palettes + 4
ld bc, 2
ld a, $5
call FarCopyWRAM
@@ -717,13 +717,13 @@ Function16cc18: ; 16cc18
Function16cc25: ; 16cc25
ld hl, Unknown_16cfa9
- ld de, UnknBGPals + 1 palettes
+ ld de, wBGPals1 + 1 palettes
call .CopyPal
ld hl, Unknown_16cfb1
- ld de, UnknOBPals
+ ld de, wOBPals1
call .CopyPal
ld hl, Unknown_16cfb9
- ld de, UnknOBPals + 1 palettes
+ ld de, wOBPals1 + 1 palettes
call .CopyPal
ret
; 16cc41
diff --git a/mobile/mobile_5c.asm b/mobile/mobile_5c.asm
index e6effc33a..0e2f7d024 100755
--- a/mobile/mobile_5c.asm
+++ b/mobile/mobile_5c.asm
@@ -281,7 +281,7 @@ Function170cc6: ; 170cc6
ld hl, LZ_1715a4
ld de, wd000
call Decompress
- ld de, UnknBGPals
+ ld de, wBGPals1
ld hl, vTiles0
lb bc, $6, $53
call Get2bpp
@@ -716,7 +716,7 @@ Function171ccd: ; 171ccd (5c:5ccd)
ld a, $5
ld [rSVBK], a
ld hl, Palette_171d71
- ld de, UnknBGPals
+ ld de, wBGPals1
ld bc, 8 palettes
call CopyBytes
ld hl, EngineBuffer5
@@ -884,11 +884,11 @@ Function172eb9:
ld a, $5
ld [rSVBK], a
ld hl, Palette_172edf
- ld de, UnknBGPals
+ ld de, wBGPals1
ld bc, 8 palettes
call CopyBytes
ld hl, Palette_172edf
- ld de, BGPals
+ ld de, wBGPals2
ld bc, 8 palettes
call CopyBytes
call SetPalettes
diff --git a/mobile/mobile_5e.asm b/mobile/mobile_5e.asm
index ea54b9f98..daef4318f 100644
--- a/mobile/mobile_5e.asm
+++ b/mobile/mobile_5e.asm
@@ -760,26 +760,26 @@ Function17aba0: ; 17aba0 (5e:6ba0)
Function17abcf: ; 17abcf (5e:6bcf)
ld a, [rSVBK]
push af
- ld a, BANK(UnknBGPals)
+ ld a, BANK(wBGPals1)
ld [rSVBK], a
ld hl, Palette_17ac55
- ld de, UnknBGPals ; $d000
+ ld de, wBGPals1 ; $d000
ld bc, 6 palettes
call CopyBytes
ld hl, Palette_17ac95
- ld de, UnknOBPals
+ ld de, wOBPals1
ld bc, 8 palettes
call CopyBytes
ld hl, GFX_17afa5 + $510
- ld de, UnknOBPals palette 1
+ ld de, wOBPals1 palette 1
ld bc, 2 palettes
call CopyBytes
ld hl, MapObjectPals palette 1
- ld de, UnknOBPals palette 3
+ ld de, wOBPals1 palette 3
ld bc, 1 palettes
ld a, BANK(MapObjectPals)
call FarCopyBytes
diff --git a/mobile/mobile_5f.asm b/mobile/mobile_5f.asm
index 1e6ed4a02..5731f01fc 100644
--- a/mobile/mobile_5f.asm
+++ b/mobile/mobile_5f.asm
@@ -44,11 +44,11 @@ Function17c000: ; 17c000
ld a, [rSVBK]
push af
- ld a, 5 ; BANK(UnknBGPals)
+ ld a, 5 ; BANK(wBGPals1)
ld [rSVBK], a
ld hl, HaveWantPals
- ld de, UnknBGPals
+ ld de, wBGPals1
ld bc, 16 palettes
call CopyBytes
@@ -662,7 +662,7 @@ Function17d370: ; 17d370
ld a, $6
call GetSRAMBank
ld hl, $a006
- ld de, UnknBGPals
+ ld de, wBGPals1
ld bc, $1000
call CopyBytes
call CloseSRAM
@@ -703,7 +703,7 @@ Function17d405:
ld a, $5
ld [rSVBK], a
ld hl, Palette_17eff6
- ld de, UnknBGPals
+ ld de, wBGPals1
ld bc, 8 palettes
call CopyBytes
call SetPalettes
@@ -970,7 +970,7 @@ Function17d5f6: ; 17d5f6
ld a, $5
ld [rSVBK], a
ld hl, $c608
- ld de, UnknBGPals
+ ld de, wBGPals1
ld bc, 8 palettes
call CopyBytes
ld a, $4
@@ -1218,7 +1218,7 @@ Function17d78d: ; 17d78d
call GetSRAMBank
ld hl, $a006
add hl, bc
- ld de, UnknBGPals
+ ld de, wBGPals1
ld bc, $1000
call CopyBytes
call CloseSRAM
@@ -1342,7 +1342,7 @@ Function17d85d: ; 17d85d
ld a, [hli]
ld d, a
push hl
- ld hl, UnknBGPals
+ ld hl, wBGPals1
add hl, de
ld de, wcc60
.asm_17d86c
@@ -1411,7 +1411,7 @@ Function17d85d: ; 17d85d
ld a, $3
ld [rSVBK], a
ld hl, $c608
- ld de, UnknBGPals
+ ld de, wBGPals1
ld b, $0
call CopyBytes
ld a, $4
@@ -1446,7 +1446,7 @@ Function17d902: ; 17d902
call Function17e41e
call Function17e32b
pop de
- ld hl, UnknBGPals
+ ld hl, wBGPals1
add hl, de
ld de, wcc60
.asm_17d918
@@ -1963,7 +1963,7 @@ Function17dca9: ; 17dca9
Function17dcaf:
ld a, $5
ld [rSVBK], a
- ld hl, UnknBGPals
+ ld hl, wBGPals1
ld de, 1 palettes
ld c, 8
.asm_17dcbb
@@ -3135,7 +3135,7 @@ Function17e409: ; 17e409
; 17e40f
Function17e40f: ; 17e40f
- ld de, UnknBGPals
+ ld de, wBGPals1
add hl, de
jr Function17e41e
@@ -4377,7 +4377,7 @@ Function17f3f0: ; 17f3f0
ld e, a
ld a, [hli]
ld d, a
- ld hl, UnknBGPals
+ ld hl, wBGPals1
add hl, de
ld e, l
ld d, h
diff --git a/tilesets/animations.asm b/tilesets/animations.asm
index 56741fd1e..9234a411f 100644
--- a/tilesets/animations.asm
+++ b/tilesets/animations.asm
@@ -954,7 +954,7 @@ TileAnimationPalette: ; fc6d7
jr z, .color2
.color1
- ld hl, UnknBGPals + palette 3 + 2
+ ld hl, wBGPals1 + palette 3 + 2
ld a, [hli]
ld [rBGPD], a
ld a, [hli]
@@ -962,7 +962,7 @@ TileAnimationPalette: ; fc6d7
jr .end
.color0
- ld hl, UnknBGPals + palette 3
+ ld hl, wBGPals1 + palette 3
ld a, [hli]
ld [rBGPD], a
ld a, [hli]
@@ -970,7 +970,7 @@ TileAnimationPalette: ; fc6d7
jr .end
.color2
- ld hl, UnknBGPals + palette 3 + 4
+ ld hl, wBGPals1 + palette 3 + 4
ld a, [hli]
ld [rBGPD], a
ld a, [hli]
@@ -1007,11 +1007,11 @@ FlickeringCaveEntrancePalette: ; fc71e
ld a, [hVBlankCounter]
and %00000010
jr nz, .bit1set
- ld hl, UnknBGPals + palette 4
+ ld hl, wBGPals1 + palette 4
jr .okay
.bit1set
- ld hl, UnknBGPals + palette 4 + 2
+ ld hl, wBGPals1 + palette 4 + 2
.okay
ld a, [hli]
diff --git a/tilesets/special_palettes.asm b/tilesets/special_palettes.asm
index de7d09963..761b15348 100644
--- a/tilesets/special_palettes.asm
+++ b/tilesets/special_palettes.asm
@@ -54,8 +54,8 @@ LoadSpecialMapPalette: ; 494ac
; 494f2
LoadPokeComPalette: ; 494f2
- ld a, BANK(UnknBGPals)
- ld de, UnknBGPals
+ ld a, BANK(wBGPals1)
+ ld de, wBGPals1
ld hl, PokeComPalette
ld bc, 8 palettes
call FarCopyWRAM
@@ -67,8 +67,8 @@ INCLUDE "data/palettes/tilesets/pokecom_center.pal"
; 49541
LoadBattleTowerPalette: ; 49541
- ld a, BANK(UnknBGPals)
- ld de, UnknBGPals
+ ld a, BANK(wBGPals1)
+ ld de, wBGPals1
ld hl, BattleTowerPalette
ld bc, 8 palettes
call FarCopyWRAM
@@ -80,8 +80,8 @@ INCLUDE "data/palettes/tilesets/battle_tower.pal"
; 49590
LoadIcePathPalette: ; 49590
- ld a, BANK(UnknBGPals)
- ld de, UnknBGPals
+ ld a, BANK(wBGPals1)
+ ld de, wBGPals1
ld hl, IcePathPalette
ld bc, 8 palettes
call FarCopyWRAM
@@ -93,8 +93,8 @@ INCLUDE "data/palettes/tilesets/ice_path.pal"
; 495df
LoadHousePalette: ; 495df
- ld a, BANK(UnknBGPals)
- ld de, UnknBGPals
+ ld a, BANK(wBGPals1)
+ ld de, wBGPals1
ld hl, HousePalette
ld bc, 8 palettes
call FarCopyWRAM
@@ -106,8 +106,8 @@ INCLUDE "data/palettes/tilesets/house_1.pal"
; 4962e
LoadRadioTowerPalette: ; 4962e
- ld a, BANK(UnknBGPals)
- ld de, UnknBGPals
+ ld a, BANK(wBGPals1)
+ ld de, wBGPals1
ld hl, RadioTowerPalette
ld bc, 8 palettes
call FarCopyWRAM
@@ -169,23 +169,23 @@ MansionPalette4: ; 496bd
; 496c5
LoadMansionPalette: ; 496c5
- ld a, BANK(UnknBGPals)
- ld de, UnknBGPals
+ ld a, BANK(wBGPals1)
+ ld de, wBGPals1
ld hl, MansionPalette1
ld bc, 8 palettes
call FarCopyWRAM
- ld a, BANK(UnknBGPals)
- ld de, UnknBGPals palette PAL_BG_YELLOW
+ ld a, BANK(wBGPals1)
+ ld de, wBGPals1 palette PAL_BG_YELLOW
ld hl, MansionPalette2
ld bc, 1 palettes
call FarCopyWRAM
- ld a, BANK(UnknBGPals)
- ld de, UnknBGPals palette PAL_BG_WATER
+ ld a, BANK(wBGPals1)
+ ld de, wBGPals1 palette PAL_BG_WATER
ld hl, MansionPalette3
ld bc, 1 palettes
call FarCopyWRAM
- ld a, BANK(UnknBGPals)
- ld de, UnknBGPals palette PAL_BG_ROOF
+ ld a, BANK(wBGPals1)
+ ld de, wBGPals1 palette PAL_BG_ROOF
ld hl, MansionPalette4
ld bc, 1 palettes
call FarCopyWRAM
diff --git a/wram.asm b/wram.asm
index 317b31a1c..5b445e5ba 100644
--- a/wram.asm
+++ b/wram.asm
@@ -2880,10 +2880,10 @@ w3_dffc:: ds 4
SECTION "GBC Video", WRAMX
; eight 4-color palettes each
-UnknBGPals:: ds 8 palettes ; d000
-UnknOBPals:: ds 8 palettes ; d040
-BGPals:: ds 8 palettes ; d080
-OBPals:: ds 8 palettes ; d0c0
+wBGPals1:: ds 8 palettes ; d000
+wOBPals1:: ds 8 palettes ; d040
+wBGPals2:: ds 8 palettes ; d080
+wOBPals2:: ds 8 palettes ; d0c0
LYOverrides:: ds SCREEN_HEIGHT_PX ; d100
LYOverridesEnd:: ; d190
diff --git a/engine/crystal_intro.asm b/engine/crystal_intro.asm
index 449a5bf82..302490a3b 100755
--- a/engine/crystal_intro.asm
+++ b/engine/crystal_intro.asm
@@ -322,9 +322,9 @@ GameFreakLogoScene4: ; e4776 (39:4776)
ld a, $5
ld [rSVBK], a
ld a, [hli]
- ld [OBPals + 12], a
+ ld [wOBPals2 + 12], a
ld a, [hli]
- ld [OBPals + 13], a
+ ld [wOBPals2 + 13], a
pop af
ld [rSVBK], a
ld a, $1
@@ -483,11 +483,11 @@ IntroScene1: ; e495b (39:495b)
ld a, $5
ld [rSVBK], a
ld hl, Palette_365ad
- ld de, UnknBGPals
+ ld de, wBGPals1
ld bc, 16 palettes
call CopyBytes
ld hl, Palette_365ad
- ld de, BGPals
+ ld de, wBGPals2
ld bc, 16 palettes
call CopyBytes
pop af
@@ -556,11 +556,11 @@ IntroScene3: ; e49fd (39:49fd)
ld a, $5
ld [rSVBK], a
ld hl, Palette_e5edd
- ld de, UnknBGPals
+ ld de, wBGPals1
ld bc, 16 palettes
call CopyBytes
ld hl, Palette_e5edd
- ld de, BGPals
+ ld de, wBGPals2
ld bc, 16 palettes
call CopyBytes
pop af
@@ -622,11 +622,11 @@ IntroScene5: ; e4a7a (39:4a7a)
ld a, $5
ld [rSVBK], a
ld hl, Palette_365ad
- ld de, UnknBGPals
+ ld de, wBGPals1
ld bc, 16 palettes
call CopyBytes
ld hl, Palette_365ad
- ld de, BGPals
+ ld de, wBGPals2
ld bc, 16 palettes
call CopyBytes
pop af
@@ -729,12 +729,12 @@ IntroScene7: ; e4b3f (39:4b3f)
ld [rSVBK], a
ld hl, Palette_e5edd
- ld de, UnknBGPals
+ ld de, wBGPals1
ld bc, 16 palettes
call CopyBytes
ld hl, Palette_e5edd
- ld de, BGPals
+ ld de, wBGPals2
ld bc, 16 palettes
call CopyBytes
@@ -887,11 +887,11 @@ IntroScene11: ; e4c86 (39:4c86)
ld a, $5
ld [rSVBK], a
ld hl, Palette_365ad
- ld de, UnknBGPals
+ ld de, wBGPals1
ld bc, 16 palettes
call CopyBytes
ld hl, Palette_365ad
- ld de, BGPals
+ ld de, wBGPals2
ld bc, 16 palettes
call CopyBytes
pop af
@@ -1014,11 +1014,11 @@ IntroScene13: ; e4d6d (39:4d6d)
ld a, $5
ld [rSVBK], a
ld hl, Palette_e5edd
- ld de, UnknBGPals
+ ld de, wBGPals1
ld bc, 16 palettes
call CopyBytes
ld hl, Palette_e5edd
- ld de, BGPals
+ ld de, wBGPals2
ld bc, 16 palettes
call CopyBytes
pop af
@@ -1123,11 +1123,11 @@ IntroScene15: ; e4e40 (39:4e40)
ld a, $5
ld [rSVBK], a
ld hl, Palette_e77dd
- ld de, UnknBGPals
+ ld de, wBGPals1
ld bc, 16 palettes
call CopyBytes
ld hl, Palette_e77dd
- ld de, BGPals
+ ld de, wBGPals2
ld bc, 16 palettes
call CopyBytes
pop af
@@ -1197,11 +1197,11 @@ IntroScene17: ; e4ef5 (39:4ef5)
ld a, $5
ld [rSVBK], a
ld hl, Palette_e6d6d
- ld de, UnknBGPals
+ ld de, wBGPals1
ld bc, 16 palettes
call CopyBytes
ld hl, Palette_e6d6d
- ld de, BGPals
+ ld de, wBGPals2
ld bc, 16 palettes
call CopyBytes
pop af
@@ -1271,11 +1271,11 @@ IntroScene19: ; e4f7e (39:4f7e)
ld a, $5
ld [rSVBK], a
ld hl, Palette_e77dd
- ld de, UnknBGPals
+ ld de, wBGPals1
ld bc, 16 palettes
call CopyBytes
ld hl, Palette_e77dd
- ld de, BGPals
+ ld de, wBGPals2
ld bc, 16 palettes
call CopyBytes
pop af
@@ -1441,11 +1441,11 @@ IntroScene26: ; e50bb (39:50bb)
ld a, $5
ld [rSVBK], a
ld hl, Palette_e679d
- ld de, UnknBGPals
+ ld de, wBGPals1
ld bc, 16 palettes
call CopyBytes
ld hl, Palette_e679d
- ld de, BGPals
+ ld de, wBGPals2
ld bc, 16 palettes
call CopyBytes
pop af
@@ -1516,7 +1516,7 @@ IntroScene28: ; e5152 (39:5152)
ret
Intro_Scene24_ApplyPaletteFade: ; e5172 (39:5172)
; load the (a)th palette from .FadePals to all BGPals
ld hl, .FadePals
add l
ld l, a
@@ -1528,7 +1528,7 @@ Intro_Scene24_ApplyPaletteFade: ; e5172 (39:5172)
push af
ld a, $5
ld [rSVBK], a
- ld de, BGPals
+ ld de, wBGPals2
ld b, 8 ; number of BG pals
.loop1
push hl
@@ -1599,7 +1599,7 @@ CrystalIntro_UnownFade: ; e5223 (39:5223)
add a
ld e, a
ld d, $0
- ld hl, BGPals
+ ld hl, wBGPals2
add hl, de
inc hl
inc hl
@@ -1622,7 +1622,7 @@ CrystalIntro_UnownFade: ; e5223 (39:5223)
push hl
push bc
- ld hl, BGPals
+ ld hl, wBGPals2
ld bc, 8 palettes
xor a
call ByteFill
@@ -1726,7 +1726,7 @@ Intro_Scene20_AppearUnown: ; e5348 (39:5348)
ld [rSVBK], a
push bc
- ld de, BGPals
+ ld de, wBGPals2
ld a, c
add e
@@ -1739,7 +1739,7 @@ Intro_Scene20_AppearUnown: ; e5348 (39:5348)
call CopyBytes
pop bc
- ld de, UnknBGPals
+ ld de, wBGPals1
ld a, c
add e
ld e, a
@@ -1779,7 +1779,7 @@ Intro_FadeUnownWordPals: ; e539d (39:539d)
add a
ld e, a
ld d, $0
- ld hl, BGPals
+ ld hl, wBGPals2
add hl, de
rept 4
inc hl
@@ -1949,7 +1949,7 @@ Intro_ClearBGPals: ; e54a3 (39:54a3)
ld a, $5
ld [rSVBK], a
- ld hl, BGPals
+ ld hl, wBGPals2
ld bc, 16 palettes
xor a
call ByteFill
@@ -1516,7 +1516,7 @@ IntroScene28: ; e5152 (39:5152)
ret
Intro_Scene24_ApplyPaletteFade: ; e5172 (39:5172)
-; load the (a)th palette from .FadePals to all BGPals
+; load the (a)th palette from .FadePals to all wBGPals2
ld hl, .FadePals
add l
diff --git a/home/palettes.asm b/home/palettes.asm
index bf414eee7..d5d6a0530 100644
--- a/home/palettes.asm
+++ b/home/palettes.asm
@@ -2,8 +2,8 @@
UpdatePalsIfCGB:: ; c2f
; update bgp data from BGPals
; update obp data from OBPals
; return carry if successful
; check cgb
@@ -24,10 +24,10 @@ ForceUpdateCGBPals:: ; c37
ld a, [rSVBK]
push af
- ld a, BANK(BGPals)
+ ld a, BANK(wBGPals2)
ld [rSVBK], a
- ld hl, BGPals
+ ld hl, wBGPals2
; copy 8 pals to bgpd
ld a, %10000000 ; auto increment, index 0
@@ -43,7 +43,7 @@ endr
dec b
jr nz, .bgp
-; hl is now OBPals
+; hl is now wOBPals2
; copy 8 pals to obpd
ld a, %10000000 ; auto increment, index 0
@@ -90,12 +90,12 @@ DmgToCgbBGPals:: ; c9f
ld a, [rSVBK]
push af
- ld a, BANK(BGPals)
+ ld a, BANK(wBGPals2)
ld [rSVBK], a
; copy & reorder bg pal buffer
- ld hl, BGPals ; to
- ld de, UnknBGPals ; from
+ ld hl, wBGPals2 ; to
+ ld de, wBGPals1 ; from
; order
ld a, [rBGP]
ld b, a
@@ -138,12 +138,12 @@ DmgToCgbObjPals:: ; ccb
ld a, [rSVBK]
push af
- ld a, BANK(OBPals)
+ ld a, BANK(wOBPals2)
ld [rSVBK], a
; copy & reorder obj pal buffer
- ld hl, OBPals ; to
- ld de, UnknOBPals ; from
+ ld hl, wOBPals2 ; to
+ ld de, wOBPals1 ; from
; order
ld a, [rOBP0]
ld b, a
@@ -178,11 +178,11 @@ DmgToCgbObjPal0:: ; cf8
ld a, [rSVBK]
push af
- ld a, BANK(OBPals)
+ ld a, BANK(wOBPals2)
ld [rSVBK], a
- ld hl, OBPals palette 0
- ld de, UnknOBPals palette 0
+ ld hl, wOBPals2 palette 0
+ ld de, wOBPals1 palette 0
ld a, [rOBP0]
ld b, a
ld c, 1
@@ -216,11 +216,11 @@ DmgToCgbObjPal1:: ; d24
ld a, [rSVBK]
push af
- ld a, BANK(OBPals)
+ ld a, BANK(wOBPals2)
ld [rSVBK], a
- ld hl, OBPals palette 1
- ld de, UnknOBPals palette 1
+ ld hl, wOBPals2 palette 1
+ ld de, wOBPals1 palette 1
ld a, [rOBP1]
ld b, a
ld c, 1
@@ -325,9 +325,9 @@ Special_ReloadSpritesNoPalettes:: ; d91
ret z
ld a, [rSVBK]
push af
- ld a, BANK(BGPals)
+ ld a, BANK(wBGPals2)
ld [rSVBK], a
- ld hl, BGPals
+ ld hl, wBGPals2
ld bc, (8 palettes) + (2 palettes)
xor a
call ByteFill
@@ -2,8 +2,8 @@
UpdatePalsIfCGB:: ; c2f
-; update bgp data from BGPals
-; update obp data from OBPals
+; update bgp data from wBGPals2
+; update obp data from wOBPals2
; return carry if successful
; check cgb